package legion.muyue.best2048.data;

/**
 * Représente une requête contenant uniquement l'identifiant d'un joueur.
 * Cette classe est typiquement utilisée comme un objet de transfert de données (DTO)
 * simple pour les opérations où seul l'identifiant du joueur est nécessaire,
 * par exemple, pour rejoindre une partie, demander des informations spécifiques
 * au joueur, ou s'identifier auprès d'un service.
 */
public class PlayerIdRequest {

    /**
     * L'identifiant unique du joueur concerné par la requête.
     * Ce champ est destiné à être sérialisé (par exemple en JSON) pour la communication.
     */
    private String playerId;

    /**
     * Construit une nouvelle requête contenant un identifiant de joueur.
     *
     * @param playerId L'identifiant unique du joueur.
     * Ne doit généralement pas être null ou vide.
     */
    public PlayerIdRequest(String playerId) {
        this.playerId = playerId;
    }
}